extraSlag static method
extraSlag method to set the api domain with extra path Previously set domain will be used as base url
Example:
Service.domain("https://example.com/");
Service.extraSlag("api/");
print(Service.apiUrl); // https://example.com/api/
Implementation
static extraSlag(String? path) => _apiUrl = _url + (path ?? '');