RatingWidget class

Inheritance

Constructors

RatingWidget({Key? key, required double rating, bool showRatingValue = true, double? fontSize, MainAxisAlignment? mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment? crossAxisAlignment = CrossAxisAlignment.center, @Deprecated('Use [textColor] [ratingColor] instead') Color? color, Color? textColor = const Color(0xffFFA873), Color? ratingColor = const Color(0xffFFA873), double? ratingIconSize = 14, Color? emptyColor, RatingTextPosition? ratingTextPosition = RatingTextPosition.left, double? outOf, FontWeight? fontWeight = FontWeight.w600, IconData? starFillIcon, IconData? starHalfIcon, IconData? starEmptyIcon})
const

Properties

color Color?
final
crossAxisAlignment CrossAxisAlignment?
final
emptyColor Color?
final
fontSize double?
final
fontWeight FontWeight?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisAlignment MainAxisAlignment?
final
outOf double?
final
rating double
final
ratingColor Color?
final
ratingIconSize double?
final
ratingTextPosition RatingTextPosition?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showRatingValue bool
final
starEmptyIcon IconData?
final
starFillIcon IconData?
final
starHalfIcon IconData?
final
textColor Color?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited