ToastManager class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cancelAllToasts(
) → void - cancels all toasts
-
initialize(
) → void -
show(
String message, {ToastPosition toastPosition = ToastPosition.bottom, Duration? duration, BorderRadius? borderRadius, Color? backgroundColor, Color? textColor, String? imagePath, TextAlign? messageAlignment, double messageFontSize = 14}) → void - shows context less toast